<template>
  <div class="system-parameter-set-box">
    <el-button
      class="system-button"
      type="primary"
      :loading="isBtnloading"
      size="mini"
      @click="onSubmit()"
      >保存</el-button
    >
    <el-tabs
      class="system-tabs"
      v-model="activeName"
      @tab-click="handleTabClick"
    >
      <el-tab-pane label="WMS系统参数" name="wms" style="height: 100%">
        <TableCommonView
          ref="tableListRef"
          :loading="isBtnloading"
          :table-list="wmsTableList"
          @selTableCol="selWmsTableCol"
          :showHeader="false"
          :colOpenShow="false"
        >
          <template slot="tableButton">
            <el-table-column prop="value" label="值" width="210" fixed="right">
              <template slot-scope="scope">
                <el-select
                  size="small"
                  v-if="scope.row.type == 'select'"
                  v-model="scope.row.value"
                  placeholder="请选择"
                >
                  <el-option
                    v-for="item in scope.row.select"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                  ></el-option>
                </el-select>
                <el-input
                  v-else
                  size="small"
                  v-model="scope.row.value"
                  placeholder="请输入"
                ></el-input>
              </template>
            </el-table-column>
          </template>
        </TableCommonView>
      </el-tab-pane>
    </el-tabs>
  </div>
</template>

<script>
import { saveSystemSet } from "@/api/systemSet/commonSet";
export default {
  components: {},
  props: {
    tableConfig: {
      type: Object,
      default: () => {
        return {};
      },
    },
  },
  data() {
    return {
      activeName: "wms",
      wmsTableList: {},
      showcolWms: [],
      isBtnloading: false,
    };
  },
  created() {
    this.setWmsTable();
  },
  watch: {
    tableConfig: {
      handler() {
        this.getInfo();
      },
      immediate: true,
      deep: true,
    },
  },
  methods: {
    getInfo() {
      this.activeName = "wms";
      this.wmsTableList.tableInfomation = this.tableConfig.WMS;
    },
    // wms
    setWmsTable() {
      this.wmsTableList = {
        tableInfomation: [],
        selectIndex: true,
        maxHeight: "930px",
        highlight: true,
        key: "id",
        showcol: this.showcolWms,
        allcol: [],
        tableColumn: this.setWmsTableColumn(this.showcolWms),
      };
      let allcol = [];
      for (let i = 0; i < this.wmsTableList.tableColumn.length; i++) {
        if (!this.wmsTableList.tableColumn[i].default) {
          const label = this.wmsTableList.tableColumn[i].label;
          allcol.push(label);
        }
      }
      this.wmsTableList.allcol = allcol;
    },
    setWmsTableColumn() {
      let tableColumn = [
        {
          label: "内容",
          prop: "name",
          align: "left",
          isShowColumn: true,
          default: true,
        },
      ];
      return tableColumn;
    },

    selWmsTableCol(val) {
      this.showcolWms = val;
      this.wmsTableList.tableColumn = this.setWmsTableColumn(val);
    },
    handleTabClick() {},
    onSubmit() {
      this.isBtnloading = true;
      let arr = [];
      arr = arr.concat(this.wmsTableList.tableInfomation);
      for (let i in arr) {
        delete arr[i].id;
      }
      saveSystemSet({
        sets: arr,
      })
        .then((res) => {
          if (res.code == 200) {
            this.$message.success("修改成功！");
            this.$emit("refresh");
          }
          this.isBtnloading = false;
        })
        .catch(() => {
          setTimeout(() => {
            this.isBtnloading = false;
          }, 3000);
        });
    },
  },
};
</script>

<style lang="scss" scoped>
.system-parameter-set-box {
  width: 100%;
  height: 100%;
  overflow: hidden;

  .system-button {
    float: right;
    position: relative;
    right: 20px;
    top: 5px;
    z-index: 5;
  }
  .system-tabs {
    width: 100%;
    height: 100%;
    ::v-deep .el-tabs__content {
      height: calc(100% - 55px) !important;
    }
  }
}
</style>
